@@ -17,6 +17,7 @@ class DTMessageBox(DTDialog):
 		self.setCentralWidget(self.module)
 
 		self.module.label_text.setText(text)
+		# self.module.label_text.setOpenExternalLinks(True)
 
 		if detail=="":
 			self.module.textBrowser.hide()
@@ -31,10 +32,12 @@ class DTMessageBox(DTDialog):
 			icon_pic=icon.pixmap(QSize(64,64))
 			self.module.label_icon.setPixmap(icon_pic)
 		else:
-			self.module.label_icon.setVisible(False)
-			self.module.horizontalLayout.setContentsMargins(45,10,0,5)
+			self.module.label_icon.hide()
+			self.module.horizontalLayout.setContentsMargins(30,10,0,5)
 
 		self.adjustSize()
+		MoveToCenterOfScreen(self)
+
 		self.exec_()
 
 class DTConfirmBox(DTDialog):
@@ -42,7 +45,7 @@ class DTConfirmBox(DTDialog):
 		super().__init__(parent, title)
 		self.module=MessageModule(self)
 		self.setCentralWidget(self.module)
-		
+
 		self.module.label_text.setText(text)
 
 		if detail=="":
@@ -58,4 +61,5 @@ class DTConfirmBox(DTDialog):
 			self.module.label_icon.setVisible(False)
 			self.module.horizontalLayout.setContentsMargins(45,10,0,5)
 
-		self.adjustSize()
\ No newline at end of file
+		self.adjustSize()
+		MoveToCenterOfScreen(self)
\ No newline at end of file
