@@ -22,12 +22,30 @@ from cryptography.hazmat.primitives import hashes
 from cryptography.hazmat.primitives.kdf.pbkdf2 import PBKDF2HMAC
 import colour
 
+def ShowUp(widget:QWidget):
+	"""在initializeWindow中，setCentralWidget之后调用
+	"""
+	widget.show()
+	widget.activateWindow()
+	widget.setWindowState(Qt.WindowActive)
+
+def MoveToCenterOfScreen(widget:QWidget):
+	"""在initializeWindow中，setCentralWidget之后调用
+	"""
+	widget.move((win32api.GetSystemMetrics(0)-widget.width())//2,(win32api.GetSystemMetrics(1)-widget.height())//2)
+
 def IconFromCurrentTheme(name):
 	return QIcon(":/icons/%s/%s"%(QIcon.themeName(),name))
 
 def Clear_Layout(layout):
-	for i in reversed(range(layout.count())): 
-		layout.takeAt(i).widget().deleteLater()
+	for i in reversed(range(layout.count())):
+		item=layout.itemAt(i)
+		
+		if item.spacerItem():
+			layout.removeItem(item)
+			del item
+		else:
+			item.widget().deleteLater()
 
 def Font_Resize(font,resize_ratio):
 	new_font=QFont(font)
