@@ -27,22 +27,31 @@ class DTSetting(Ui_DTSetting,QWidget):
 			self.lineEdit_password.hide()
 			self.label_password.hide()
 		
-		self.lineEdit_data_dir.setText(self.app.DataDir())
-
-		if self.app.isBackupEnable():
-			dst=self.app.BackupDst()
-			if dst==False:
-				self.lineEdit_backup.setText("")
+		if self.app.DataList()!=[]:
+			self.lineEdit_data_dir.setText(self.app.DataDir())
+			
+			if self.app.isBackupEnable():
+				dst=self.app.BackupDst()
+				if dst==None:
+					self.lineEdit_backup.setText("")
+				else:
+					self.lineEdit_backup.setText(dst)
 			else:
-				self.lineEdit_backup.setText(dst)
+				self.label_backup.hide()
+				self.lineEdit_backup.hide()
+				self.pushButton_backup.hide()
+		
 		else:
+			self.lineEdit_data_dir.hide()
+			self.label_data_dir.hide()
+			self.pushButton_data_dir.hide()
 			self.label_backup.hide()
 			self.lineEdit_backup.hide()
 			self.pushButton_backup.hide()
 
 		# font
 		self.pushButton_font.setText(self.app.Font().key().split(",")[0])
-		self.pushButton_font.setStyleSheet("font-family:%s"%self.app.Font().key().split(",")[0])
+		self.pushButton_font.setStyleSheet("font-family:%s; min-height:26px; max-height:26px;"%self.app.Font().key().split(",")[0])
 
 		# scale
 		self.spinBox_scale.setValue(self.app.Scale())
@@ -265,29 +274,29 @@ class DTSetting(Ui_DTSetting,QWidget):
 		self.app.setSaturation(float(self.slider_saturation.value()/self.slider_saturation.maximum()))
 		self.app.setLuminance(float(self.slider_luminance.value()/self.slider_luminance.maximum()))
 		self.app.setContrast(float(self.slider_contrast.value()/self.slider_contrast.maximum()))
-		self.app.initializeWindowStyle()
+		self.app.initializeWindowStyle(refresh=True)
 
 	def HueReset(self):
 		self.app.setHue(-1)
 		self.slider_Hue.setValue(0)
-		self.app.initializeWindowStyle()
+		self.app.initializeWindowStyle(refresh=True)
 		self.updateColorPreview()
 		self.updateSaturationSlider()
 	
 	def SaturationReset(self):
 		self.app.setSaturation(0.5)
 		self.slider_saturation.setValue(int(self.slider_saturation.maximum()/2))
-		self.app.initializeWindowStyle()
+		self.app.initializeWindowStyle(refresh=True)
 	
 	def LuminanceReset(self):
 		self.app.setLuminance(0.5)
 		self.slider_luminance.setValue(int(self.slider_luminance.maximum()/2))
-		self.app.initializeWindowStyle()
+		self.app.initializeWindowStyle(refresh=True)
 	
 	def ContrastReset(self):
 		self.app.setContrast(0.5)
 		self.slider_contrast.setValue(int(self.slider_contrast.maximum()/2))
-		self.app.initializeWindowStyle()
+		self.app.initializeWindowStyle(refresh=True)
 
 	def ReverseSetting(self):
 		dlg=DTFrame.DTConfirmBox(self,"Warning","You want to change text and icon from dark to light (or from light to dark)?\n\nApp will restart after the change.")
